A single line text input similar to shiny::textInput() that can be
included in an inline() wrapper.
Arguments
- id
The
inputslot that will be used to access the value.- value
The initial text contents (a character string).
- placeholder
The character string or HTML element that will appear in the textbox when it is empty, as a prompt.
- meaning
A descriptive label, for people using assistive technology such as screen readers.
- max_width
The maximum width of the text input as a CSS length (e.g.
"10em","200px"). When the text is longer than this, the input becomes horizontally scrollable. The default is"10em". UseNULLfor no limit.
Value
An inline widget to be included in an inline() wrapper.
See also
shiny::textInput for how the text input works with your Shiny server.
Examples
ui <- bslib::page_fixed(
shiny::h1("Hello!"),
inline("My name is ", inline_text("myname", "Sisyphus",
placeholder = "Enter your name", meaning = "Your name"), ".")
)