Learn R Programming

inshiny (version 0.1.2)

inshiny-package: inshiny: Compact Inline Widgets for 'shiny' Apps

Description

Provides a basic set of compact widgets for 'shiny' apps which occupy less space and can appear inline with surrounding text.

Arguments

Author

Maintainer: Nick Davies nicholas.davies@lshtm.ac.uk

See Also