Learn R Programming

inshiny (version 0.1.2)

use_inshiny: Manually include inshiny scripts and stylesheet

Description

For inshiny to work, you need to link your Shiny app to inshiny's JavaScript code and CSS stylesheets. If you use inshiny's function inline() anywhere in your Shiny UI definition, which you probably do, this happens automatically. Otherwise, you can add a call to use_inshiny() to your UI.

Usage

use_inshiny()

Arguments

Value

An htmltools::htmlDependency() object to include in your UI.

Examples

Run this code
ui <- bslib::page(
    use_inshiny(),
    shiny::h1("My slider app"),
    inline_slider("slider", 50, 0, 100)
)

Run the code above in your browser using DataLab